@@ -1,5 +1,5 @@
 // Symphonia
-// Copyright (c) 2019-2021 The Project Symphonia Developers.
+// Copyright (c) 2019-2022 The Project Symphonia Developers.
 //
 // Previous Author: Kostya Shishkov <kostya.shiskov@gmail.com>
 //
@@ -14,14 +14,14 @@
 use std::f32::consts;
 use std::fmt;
 
-use symphonia_core::errors::{decode_error, unsupported_error, Result};
-use symphonia_core::io::{ReadBitsLtr, FiniteBitStream, BitReaderLtr};
-use symphonia_core::io::vlc::{Codebook, Entry16x16};
-use symphonia_core::audio::{AudioBuffer, AudioBufferRef, AsAudioBufferRef, Signal, SignalSpec};
-use symphonia_core::codecs::{CODEC_TYPE_AAC, CodecParameters, CodecDescriptor};
+use symphonia_core::audio::{AsAudioBufferRef, AudioBuffer, AudioBufferRef, Signal, SignalSpec};
+use symphonia_core::codecs::{CodecDescriptor, CodecParameters, CODEC_TYPE_AAC};
 use symphonia_core::codecs::{Decoder, DecoderOptions, FinalizeResult};
 use symphonia_core::dsp::mdct::Imdct;
+use symphonia_core::errors::{decode_error, unsupported_error, Result};
 use symphonia_core::formats::Packet;
+use symphonia_core::io::vlc::{Codebook, Entry16x16};
+use symphonia_core::io::{BitReaderLtr, FiniteBitStream, ReadBitsLtr};
 use symphonia_core::support_codec;
 use symphonia_core::units::Duration;
 
@@ -52,7 +52,6 @@ lazy_static! {
     };
 }
 
-
 impl fmt::Display for M4AType {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{}", M4A_TYPE_NAMES[*self as usize])
@@ -91,7 +90,8 @@ impl M4AInfo {
 
         if otypeidx >= M4A_TYPES.len() {
             Ok(M4AType::Unknown)
-        } else {
+        }
+        else {
             Ok(M4A_TYPES[otypeidx])
         }
     }
@@ -153,17 +153,17 @@ impl M4AInfo {
             | M4AType::ER_BSAC
             | M4AType::ER_AAC_LD => {
                 // GASpecificConfig
-                let short_frame = bs.read_bit()?;
+                let short_frame = bs.read_bool()?;
 
                 self.samples = if short_frame { 960 } else { 1024 };
 
-                let depends_on_core = bs.read_bit()?;
+                let depends_on_core = bs.read_bool()?;
 
                 if depends_on_core {
                     let _delay = bs.read_bits_leq32(14)?;
                 }
 
-                let extension_flag = bs.read_bit()?;
+                let extension_flag = bs.read_bool()?;
 
                 if self.channels == 0 {
                     return unsupported_error("aac: program config element");
@@ -184,12 +184,12 @@ impl M4AInfo {
                         || (self.otype == M4AType::ER_AAC_Scalable)
                         || (self.otype == M4AType::ER_AAC_LD)
                     {
-                        let _section_data_resilience = bs.read_bit()?;
-                        let _scalefactors_resilience = bs.read_bit()?;
-                        let _spectral_data_resilience = bs.read_bit()?;
+                        let _section_data_resilience = bs.read_bool()?;
+                        let _scalefactors_resilience = bs.read_bool()?;
+                        let _spectral_data_resilience = bs.read_bool()?;
                     }
 
-                    let extension_flag3 = bs.read_bit()?;
+                    let extension_flag3 = bs.read_bool()?;
 
                     if extension_flag3 {
                         return unsupported_error("aac: version3 extensions");
@@ -280,19 +280,19 @@ impl M4AInfo {
             if sync == 0x2B7 {
                 let ext_otype = Self::read_object_type(&mut bs)?;
                 if ext_otype == M4AType::Sbr {
-                    self.sbr_present = bs.read_bit()?;
+                    self.sbr_present = bs.read_bool()?;
                     if self.sbr_present {
                         let _ext_srate = Self::read_sampling_frequency(&mut bs)?;
                         if bs.bits_left() >= 12 {
                             let sync = bs.read_bits_leq32(11)?;
                             if sync == 0x548 {
-                                self.ps_present = bs.read_bit()?;
+                                self.ps_present = bs.read_bool()?;
                             }
                         }
                     }
                 }
                 if ext_otype == M4AType::PS {
-                    self.sbr_present = bs.read_bit()?;
+                    self.sbr_present = bs.read_bool()?;
                     if self.sbr_present {
                         let _ext_srate = Self::read_sampling_frequency(&mut bs)?;
                     }
@@ -359,7 +359,7 @@ impl ICSInfo {
         self.prev_window_sequence = self.window_sequence;
         self.prev_window_shape = self.window_shape;
 
-        if bs.read_bit()? {
+        if bs.read_bool()? {
             return decode_error("aac: ics reserved bit set");
         }
 
@@ -381,7 +381,7 @@ impl ICSInfo {
             _ => {}
         };
 
-        self.window_shape = bs.read_bit()?;
+        self.window_shape = bs.read_bool()?;
         self.window_groups = 1;
 
         if self.window_sequence == EIGHT_SHORT_SEQUENCE {
@@ -390,7 +390,7 @@ impl ICSInfo {
             self.max_sfb = bs.read_bits_leq32(4)? as usize;
 
             for i in 0..MAX_WINDOWS - 1 {
-                self.scale_factor_grouping[i] = bs.read_bit()?;
+                self.scale_factor_grouping[i] = bs.read_bool()?;
 
                 if !self.scale_factor_grouping[i] {
                     self.group_start[self.window_groups] = i + 1;
@@ -430,7 +430,7 @@ struct LTPData {}
 
 impl LTPData {
     fn read<B: ReadBitsLtr>(bs: &mut B) -> Result<Option<Self>> {
-        let predictor_data_present = bs.read_bit()?;
+        let predictor_data_present = bs.read_bool()?;
         if !predictor_data_present {
             return Ok(None);
         }
@@ -474,7 +474,7 @@ struct PulseData {
 
 impl PulseData {
     fn read<B: ReadBitsLtr>(bs: &mut B) -> Result<Option<Self>> {
-        let pulse_data_present = bs.read_bit()?;
+        let pulse_data_present = bs.read_bool()?;
         if !pulse_data_present {
             return Ok(None);
         }
@@ -487,12 +487,7 @@ impl PulseData {
             pulse_offset[i] = bs.read_bits_leq32(5)? as u8;
             pulse_amp[i] = bs.read_bits_leq32(4)? as u8;
         }
-        Ok(Some(Self {
-            number_pulse,
-            pulse_start_sfb,
-            pulse_offset,
-            pulse_amp,
-        }))
+        Ok(Some(Self { number_pulse, pulse_start_sfb, pulse_offset, pulse_amp }))
     }
 }
 
@@ -530,8 +525,8 @@ impl TNSCoeffs {
         self.order = bs.read_bits_leq32(if long_win { 5 } else { 3 })? as usize;
         validate!(self.order <= max_order);
         if self.order > 0 {
-            self.direction = bs.read_bit()?;
-            self.compress = bs.read_bit()?;
+            self.direction = bs.read_bool()?;
+            self.compress = bs.read_bool()?;
             let mut coef_bits = 3;
             if coef_res {
                 coef_bits += 1;
@@ -575,7 +570,6 @@ impl TNSCoeffs {
 
         Ok(())
     }
-
 }
 
 #[derive(Clone, Copy)]
@@ -593,7 +587,7 @@ impl TNSData {
         num_windows: usize,
         max_order: usize,
     ) -> Result<Option<Self>> {
-        let tns_data_present = bs.read_bit()?;
+        let tns_data_present = bs.read_bool()?;
         if !tns_data_present {
             return Ok(None);
         }
@@ -603,17 +597,13 @@ impl TNSData {
         for w in 0..num_windows {
             n_filt[w] = bs.read_bits_leq32(if long_win { 2 } else { 1 })? as usize;
             if n_filt[w] != 0 {
-                coef_res[w] = bs.read_bit()?;
+                coef_res[w] = bs.read_bool()?;
             }
             for filt in 0..n_filt[w] {
                 coeffs[w][filt].read(bs, long_win, coef_res[w], max_order)?;
             }
         }
-        Ok(Some(Self {
-            n_filt,
-            coef_res,
-            coeffs,
-        }))
+        Ok(Some(Self { n_filt, coef_res, coeffs }))
     }
 }
 
@@ -625,7 +615,7 @@ struct GainControlData {
 
 impl GainControlData {
     fn read<B: ReadBitsLtr>(bs: &mut B) -> Result<Option<Self>> {
-        let gain_control_data_present = bs.read_bit()?;
+        let gain_control_data_present = bs.read_bool()?;
         if !gain_control_data_present {
             return Ok(None);
         }
@@ -704,10 +694,7 @@ impl Ics {
         self.delay = [0.0; 1024];
     }
 
-    fn decode_section_data<B: ReadBitsLtr>(
-        &mut self,
-        bs: &mut B
-    ) -> Result<()> {
+    fn decode_section_data<B: ReadBitsLtr>(&mut self, bs: &mut B) -> Result<()> {
         let sect_bits = if self.info.long_win { 5 } else { 3 };
         let sect_esc_val = (1 << sect_bits) - 1;
 
@@ -778,7 +765,6 @@ impl Ics {
 
         for g in 0..self.info.window_groups {
             for sfb in 0..self.info.max_sfb {
-
                 self.scales[g][sfb] = if self.is_zero(g, sfb) {
                     0.0
                 }
@@ -813,7 +799,6 @@ impl Ics {
 
                     get_scale(scf_normal - 100)
                 }
-
             }
         }
         Ok(())
@@ -926,7 +911,7 @@ impl Ics {
         &mut self,
         bs: &mut B,
         m4atype: M4AType,
-        common_window: bool
+        common_window: bool,
     ) -> Result<()> {
         self.global_gain = bs.read_bits_leq32(8)? as u8;
 
@@ -958,7 +943,7 @@ impl Ics {
         match m4atype {
             M4AType::Ssr => self.gain_control = GainControlData::read(bs)?,
             _ => {
-                let gain_control_data_present = bs.read_bit()?;
+                let gain_control_data_present = bs.read_bool()?;
                 validate!(!gain_control_data_present);
             }
         }
@@ -971,7 +956,6 @@ impl Ics {
         self.place_pulses();
 
         if let Some(ref tns_data) = self.tns_data {
-
             let tns_max_bands = (if self.info.long_win {
                 TNS_MAX_LONG_BANDS[srate_idx]
             }
@@ -1096,7 +1080,6 @@ fn decode_quads<B: ReadBitsLtr>(
     scale: f32,
     dst: &mut [f32],
 ) -> Result<()> {
-
     let pow43_table: &[f32; 8192] = &POW43_TABLE;
 
     for out in dst.chunks_mut(4) {
@@ -1104,7 +1087,7 @@ fn decode_quads<B: ReadBitsLtr>(
         if unsigned {
             for (out, &quad) in out.iter_mut().zip(&AAC_QUADS[cw]) {
                 if quad != 0 {
-                    *out = if bs.read_bit()? {
+                    *out = if bs.read_bool()? {
                         -pow43_table[quad as usize] * scale
                     }
                     else {
@@ -1138,7 +1121,6 @@ fn decode_pairs<B: ReadBitsLtr>(
     scale: f32,
     dst: &mut [f32],
 ) -> Result<()> {
-
     let pow43_table: &[f32; 8192] = &POW43_TABLE;
 
     for out in dst.chunks_mut(2) {
@@ -1148,10 +1130,10 @@ fn decode_pairs<B: ReadBitsLtr>(
         let mut y = (cw % modulo) as i16;
 
         if unsigned {
-            if x != 0 && bs.read_bit()? {
+            if x != 0 && bs.read_bool()? {
                 x = -x;
             }
-            if y != 0 && bs.read_bit()? {
+            if y != 0 && bs.read_bool()? {
                 y = -y;
             }
         }
@@ -1226,7 +1208,7 @@ impl ChannelPair {
     }
 
     fn decode_ga_cpe<B: ReadBitsLtr>(&mut self, bs: &mut B, m4atype: M4AType) -> Result<()> {
-        let common_window = bs.read_bit()?;
+        let common_window = bs.read_bool()?;
         self.common_window = common_window;
 
         if common_window {
@@ -1240,7 +1222,7 @@ impl ChannelPair {
                 1 => {
                     for g in 0..self.ics0.info.window_groups {
                         for sfb in 0..self.ics0.info.max_sfb {
-                            self.ms_used[g][sfb] = bs.read_bit()?;
+                            self.ms_used[g][sfb] = bs.read_bool()?;
                         }
                     }
                 }
@@ -1252,7 +1234,7 @@ impl ChannelPair {
                     }
                 }
                 3 => return decode_error("aac: invalid mid-side mask"),
-                _ => unreachable!()
+                _ => unreachable!(),
             }
 
             self.ics1.info = self.ics0.info;
@@ -1265,7 +1247,6 @@ impl ChannelPair {
         if common_window && self.ms_mask_present != 0 {
             let mut g = 0;
             for w in 0..self.ics0.info.num_windows {
-
                 if w > 0 && !self.ics0.info.scale_factor_grouping[w - 1] {
                     g += 1;
                 }
@@ -1282,7 +1263,7 @@ impl ChannelPair {
 
                         let scale = match dir {
                             true => -self.ics1.scales[g][sfb],
-                            _    =>  self.ics1.scales[g][sfb],
+                            _ => self.ics1.scales[g][sfb],
                         };
 
                         let left = &self.ics0.coeffs[start..end];
@@ -1347,20 +1328,8 @@ impl Dsp {
     fn new() -> Self {
         let mut kbd_long_win: [f32; 1024] = [0.0; 1024];
         let mut kbd_short_win: [f32; 128] = [0.0; 128];
-        generate_window(
-            WindowType::KaiserBessel(4.0),
-            1.0,
-            1024,
-            true,
-            &mut kbd_long_win,
-        );
-        generate_window(
-            WindowType::KaiserBessel(6.0),
-            1.0,
-            128,
-            true,
-            &mut kbd_short_win,
-        );
+        generate_window(WindowType::KaiserBessel(4.0), 1.0, 1024, true, &mut kbd_long_win);
+        generate_window(WindowType::KaiserBessel(6.0), 1.0, 128, true, &mut kbd_short_win);
         let mut sine_long_win: [f32; 1024] = [0.0; 1024];
         let mut sine_short_win: [f32; 128] = [0.0; 128];
         generate_window(WindowType::Sine, 1.0, 1024, true, &mut sine_long_win);
@@ -1371,8 +1340,8 @@ impl Dsp {
             kbd_short_win,
             sine_long_win,
             sine_short_win,
-            imdct_long: Imdct::new(1024),
-            imdct_short: Imdct::new(128),
+            imdct_long: Imdct::new_scaled(1024, 1.0 / 2048.0),
+            imdct_short: Imdct::new_scaled(128, 1.0 / 256.0),
             tmp: [0.0; 2048],
             ew_buf: [0.0; 1152],
         }
@@ -1388,14 +1357,13 @@ impl Dsp {
         prev_window_shape: bool,
         dst: &mut [f32],
     ) {
-
         let (long_win, short_win) = match window_shape {
-            true  => (&self.kbd_long_win , &self.kbd_short_win ),
+            true => (&self.kbd_long_win, &self.kbd_short_win),
             false => (&self.sine_long_win, &self.sine_short_win),
         };
 
         let (prev_long_win, prev_short_win) = match prev_window_shape {
-            true  => (&self.kbd_long_win , &self.kbd_short_win ),
+            true => (&self.kbd_long_win, &self.kbd_short_win),
             false => (&self.sine_long_win, &self.sine_short_win),
         };
 
@@ -1404,11 +1372,11 @@ impl Dsp {
 
         // Inverse MDCT
         if seq != EIGHT_SHORT_SEQUENCE {
-            self.imdct_long.imdct(coeffs, &mut self.tmp, 1.0 / 2048.0);
+            self.imdct_long.imdct(coeffs, &mut self.tmp);
         }
         else {
             for (ain, aout) in coeffs.chunks(128).zip(self.tmp.chunks_mut(256)) {
-                self.imdct_short.imdct(ain, aout, 1.0 / 256.0);
+                self.imdct_short.imdct(ain, aout);
             }
 
             self.ew_buf = [0.0; 1152];
@@ -1416,13 +1384,13 @@ impl Dsp {
             for (w, src) in self.tmp.chunks(256).enumerate() {
                 if w > 0 {
                     for i in 0..128 {
-                        self.ew_buf[w * 128 + i +   0] += src[i +   0] * short_win[i];
+                        self.ew_buf[w * 128 + i + 0] += src[i + 0] * short_win[i];
                         self.ew_buf[w * 128 + i + 128] += src[i + 128] * short_win[127 - i];
                     }
                 }
                 else {
                     for i in 0..128 {
-                        self.ew_buf[i +   0] = src[i +   0] * prev_short_win[i];
+                        self.ew_buf[i + 0] = src[i + 0] * prev_short_win[i];
                         self.ew_buf[i + 128] = src[i + 128] * short_win[127 - i];
                     }
                 }
@@ -1473,7 +1441,8 @@ impl Dsp {
                 }
             }
             LONG_START_SEQUENCE => {
-                delay[..SHORT_WIN_POINT0].copy_from_slice(&self.tmp[1024..(SHORT_WIN_POINT0 + 1024)]);
+                delay[..SHORT_WIN_POINT0]
+                    .copy_from_slice(&self.tmp[1024..(SHORT_WIN_POINT0 + 1024)]);
 
                 for i in SHORT_WIN_POINT0..SHORT_WIN_POINT1 {
                     delay[i] = self.tmp[i + 1024] * short_win[127 - (i - SHORT_WIN_POINT0)];
@@ -1502,18 +1471,15 @@ pub struct AacDecoder {
 }
 
 impl AacDecoder {
-
     fn set_pair(&mut self, pair_no: usize, channel: usize, pair: bool) -> Result<()> {
         if self.pairs.len() <= pair_no {
-            self.pairs
-                .push(ChannelPair::new(pair, channel, self.sbinfo));
+            self.pairs.push(ChannelPair::new(pair, channel, self.sbinfo));
         }
         else {
             validate!(self.pairs[pair_no].channel == channel);
             validate!(self.pairs[pair_no].is_pair == pair);
         }
-        validate!(if pair { channel + 1 }
-            else { channel } < self.m4ainfo.channels);
+        validate!(if pair { channel + 1 } else { channel } < self.m4ainfo.channels);
         Ok(())
     }
 
@@ -1555,7 +1521,7 @@ impl AacDecoder {
                 4 => {
                     // ID_DSE
                     let _id = bs.read_bits_leq32(4)?;
-                    let align = bs.read_bit()?;
+                    let align = bs.read_bool()?;
                     let mut count = bs.read_bits_leq32(8)? as u32;
                     if count == 255 {
                         count += bs.read_bits_leq32(8)? as u32;
@@ -1602,11 +1568,29 @@ impl AacDecoder {
     //     }
     // }
 
+    fn decode_inner(&mut self, packet: &Packet) -> Result<()> {
+        // Clear the audio output buffer.
+        self.buf.clear();
+        self.buf.render_reserved(None);
+
+        let mut bs = BitReaderLtr::new(packet.buf());
+
+        // Choose decode step based on the object type.
+        match self.m4ainfo.otype {
+            M4AType::Lc => self.decode_ga(&mut bs)?,
+            _ => return unsupported_error("aac: object type"),
+        }
+
+        Ok(())
+    }
 }
 
 impl Decoder for AacDecoder {
-
     fn try_new(params: &CodecParameters, _: &DecoderOptions) -> Result<Self> {
+        // This decoder only supports AAC.
+        if params.codec != CODEC_TYPE_AAC {
+            return unsupported_error("aac: invalid codec type");
+        }
 
         let mut m4ainfo = M4AInfo::new();
 
@@ -1616,6 +1600,9 @@ impl Decoder for AacDecoder {
             m4ainfo.read(extra_data_buf)?;
         }
         else {
+            validate!(params.sample_rate.is_some());
+            validate!(params.channels.is_some());
+
             // Otherwise, assume there is no ASC and use the codec parameters for ADTS.
             m4ainfo.srate = params.sample_rate.unwrap();
             m4ainfo.otype = M4AType::Lc;
@@ -1631,10 +1618,7 @@ impl Decoder for AacDecoder {
             return unsupported_error("aac: aac too complex");
         }
 
-        let spec = SignalSpec::new(
-            m4ainfo.srate,
-            map_channels(m4ainfo.channels as u32).unwrap()
-        );
+        let spec = SignalSpec::new(m4ainfo.srate, map_channels(m4ainfo.channels as u32).unwrap());
 
         let duration = m4ainfo.samples as Duration;
         let srate = m4ainfo.srate;
@@ -1656,9 +1640,7 @@ impl Decoder for AacDecoder {
     }
 
     fn supported_codecs() -> &'static [CodecDescriptor] {
-        &[
-            support_codec!(CODEC_TYPE_AAC, "aac", "Advanced Audio Coding"),
-        ]
+        &[support_codec!(CODEC_TYPE_AAC, "aac", "Advanced Audio Coding")]
     }
 
     fn codec_params(&self) -> &CodecParameters {
@@ -1666,29 +1648,26 @@ impl Decoder for AacDecoder {
     }
 
     fn decode(&mut self, packet: &Packet) -> Result<AudioBufferRef<'_>> {
-        // Clear the audio output buffer.
-        self.buf.clear();
-        self.buf.render_reserved(None);
-
-        let mut bs = BitReaderLtr::new(packet.buf());
-
-        // Choose decode step based on the object type.
-        match self.m4ainfo.otype {
-            M4AType::Lc => self.decode_ga(&mut bs)?,
-            _           => return unsupported_error("aac: object type"),
+        if let Err(e) = self.decode_inner(packet) {
+            self.buf.clear();
+            Err(e)
+        }
+        else {
+            Ok(self.buf.as_audio_buffer_ref())
         }
-
-        Ok(self.buf.as_audio_buffer_ref())
     }
 
     fn finalize(&mut self) -> FinalizeResult {
         Default::default()
     }
+
+    fn last_decoded(&self) -> AudioBufferRef<'_> {
+        self.buf.as_audio_buffer_ref()
+    }
 }
 
-const AAC_UNSIGNED_CODEBOOK: [bool; 11] = [
-    false, false, true, true, false, false, true, true, true, true, true,
-];
+const AAC_UNSIGNED_CODEBOOK: [bool; 11] =
+    [false, false, true, true, false, false, true, true, true, true, true];
 
 const AAC_CODEBOOK_MODULO: [u16; 7] = [9, 9, 8, 8, 13, 13, 17];
 
@@ -1797,9 +1776,8 @@ const SWB_OFFSET_8K_LONG: [usize; 40 + 1] = [
     1024,
 ];
 
-const SWB_OFFSET_8K_SHORT: [usize; 15 + 1] = [
-    0, 4, 8, 12, 16, 20, 24, 28, 36, 44, 52, 60, 72, 88, 108, 128,
-];
+const SWB_OFFSET_8K_SHORT: [usize; 15 + 1] =
+    [0, 4, 8, 12, 16, 20, 24, 28, 36, 44, 52, 60, 72, 88, 108, 128];
 
 const SWB_OFFSET_16K_LONG: [usize; 43 + 1] = [
     0, 8, 16, 24, 32, 40, 48, 56, 64, 72, 80, 88, 100, 112, 124, 136, 148, 160, 172, 184, 196, 212,
@@ -1807,9 +1785,8 @@ const SWB_OFFSET_16K_LONG: [usize; 43 + 1] = [
     896, 960, 1024,
 ];
 
-const SWB_OFFSET_16K_SHORT: [usize; 15 + 1] = [
-    0, 4, 8, 12, 16, 20, 24, 28, 32, 40, 48, 60, 72, 88, 108, 128,
-];
+const SWB_OFFSET_16K_SHORT: [usize; 15 + 1] =
+    [0, 4, 8, 12, 16, 20, 24, 28, 32, 40, 48, 60, 72, 88, 108, 128];
 
 const SWB_OFFSET_24K_LONG: [usize; 47 + 1] = [
     0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44, 52, 60, 68, 76, 84, 92, 100, 108, 116, 124, 136,
@@ -1817,9 +1794,8 @@ const SWB_OFFSET_24K_LONG: [usize; 47 + 1] = [
     704, 768, 832, 896, 960, 1024,
 ];
 
-const SWB_OFFSET_24K_SHORT: [usize; 15 + 1] = [
-    0, 4, 8, 12, 16, 20, 24, 28, 36, 44, 52, 64, 76, 92, 108, 128,
-];
+const SWB_OFFSET_24K_SHORT: [usize; 15 + 1] =
+    [0, 4, 8, 12, 16, 20, 24, 28, 36, 44, 52, 64, 76, 92, 108, 128];
 
 const SWB_OFFSET_64K_LONG: [usize; 47 + 1] = [
     0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44, 48, 52, 56, 64, 72, 80, 88, 100, 112, 124, 140,
